@@ -19,6 +19,19 @@
 #'  duration = max(year) - min(year), 
 #'  nteams = length(unique(team)))
 summarise <- function(.data, ...) {
-  quickdf(eval(substitute(list(...)), .data, parent.frame()))
+  cols <- eval(substitute(list(...)), .data, parent.frame())
+  
+  # ... not a named list, figure out names by deparsing call
+  if(is.null(names(cols))) {
+    missing_names <-  rep(TRUE, length(cols))
+  } else {
+    missing_names <- names(cols) == ""
+  }
+  if (any(missing_names)) {
+    names <- unname(unlist(lapply(match.call(expand = FALSE)$`...`, deparse)))
+    names(cols)[missing_names] <- names[missing_names]
+  }
+
+  quickdf(cols)
 }
 summarize <- summarise
