@@ -1,14 +1,14 @@
-# An indexed array
-# Create a indexed array, a space efficient way of indexing into a large array
-# 
-# @arguments environment containing data frame
-# @argument list of indices
-# @keyword internal
-# @alias [[.indexed_array
-# @alias names.indexed_array
-# @alias length.indexed_array
+#' An indexed array.
+#' Create a indexed array, a space efficient way of indexing into a large
+#' array.
+#' 
+#' @param env environment containing data frame
+#' @param index list of indices
+#' @keywords internal
+#' @aliases indexed_array [[.indexed_array names.indexed_array
+#'   length.indexed_array
 indexed_array <- function(env, index) {
-  exact <- all(laply(index, is.numeric))
+  exact <- all(unlist(llply(index, is.numeric)))
 
   # Situations that should use [
   #   * data.frame
@@ -30,8 +30,11 @@ indexed_array <- function(env, index) {
     subs <- c("[", "]")    
   }
   
+  # Don't drop if data is a data frame
+  drop <- !is.data.frame(env$data)
+  
   structure(
-    list(env = env, index = index, subs = subs),
+    list(env = env, index = index, drop = drop, subs = subs),
     class = c("indexed_array", "indexed")
   )
 }
@@ -44,8 +47,8 @@ length.indexed_array <- function(x) nrow(x$index)
   ## This is very slow because we have to create a copy to use do.call
   # do.call(x$subs, c(list(x$env$data), indices, drop=TRUE))
 
-  call <- paste("x$env$data", x$subs[1], indices, ", drop = TRUE", x$subs[2], 
-    sep = "")
+  call <- paste("x$env$data", 
+    x$subs[1], indices, ", drop = ", x$drop, x$subs[2], sep = "")
   eval(parse(text = call))
 }
 
